@@ -1,6 +1,6 @@
 use chunk_io::Packet;
 use messages::MessagePayload;
-use ::sessions::client::ClientSessionEvent;
+use sessions::client::ClientSessionEvent;
 
 /// A single result that is returned when the client session performs an action
 /// or receives messages from the server.
@@ -18,4 +18,4 @@ pub enum ClientSessionResult {
     /// The server session received a message that it could not handle.  This result
     /// allows the consumer application to do something with it if it wants to (special logging)
     UnhandleableMessageReceived(MessagePayload),
-}
\ No newline at end of file
+}
